@@ -1,14 +1,14 @@
 class DatasheetDoesNotExist(Exception):
-    """"""
-
+    """
+    数表不存在
+    """
     pass
 
 
 class RecordDoesNotExist(Exception):
     """
-    查询的即记录不存在
+    记录不存在
     """
-
     pass
 
 
@@ -34,3 +34,17 @@ class ErrorFieldKey(Exception):
     """
 
     pass
+
+
+class ErrorSortParams(Exception):
+    """
+    错误的排序规则
+    """
+    pass
+
+
+class UploadFileError(Exception):
+    """
+    上传附件失败
+    """
+    pass
